Trytond Mail
=============

.. image:: https://secure.travis-ci.org/openlabs/trytond-mail.png?branch=develop
  :target: https://travis-ci.org/openlabs/trytond-mail

.. image:: https://coveralls.io/repos/openlabs/trytond-mail/badge.png
  :target: https://coveralls.io/r/openlabs/trytond-mail
